/*-- $Workfile: bundesversammlung.js $ ---------------------------------
This javascript script extracts the list of mail addresses of the Swiss parliament.
Version    : $Header: /Bundesarchiv/ArchiveFormats/MapiExport/mapiexport.js 4     8.06.07 15:41 Hartwig $
             $NoKeywords: $
Application: Open Government Data
Platform   : ECMAScript, Windows
Description: Mail addresses are extracted from http://www.parlament.ch
------------------------------------------------------------------------
Created    : Hartwig Thomas, 13. April 2011
Copyright  : Enter AG, Zurich, Switzerland, 2011
This file is part of the project Bundesversammlung.
bundesversammlung.js is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 2 of the License, or
any later version.
bundesversammlung.js is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with Bundesversammlung. If not, see <http://www.gnu.org/licenses/>.
----------------------------------------------------------------------*/
var g_sProgram = "Bundesversammlung 1.0";
var g_sBanner = "Export of mail addresses of Swiss parliament from http://www.parlament.ch;\n" +
  "(c) 2011 Enter AG, Zurich, Switzerland\n" +
  "This program comes with ABSOLUTELY NO WARRANTY; It is free software,\n" +
  "and you are welcome to redistribute it under certain conditions;\n" +
  "Use option /copy for details.\n";

/* the file system object is needed everywhere */
g_fso = new ActiveXObject("Scripting.FileSystemObject");

/* set verbose to true for debugging */
g_bVerbose = WScript.Arguments.Named.Exists("v");

/*----------------------------------------------------------------------
getScriptDir returns this script's full path name at run time
----------------------------------------------------------------------*/
function getScriptDir()
{
  var fileScript = g_fso.getFile(WScript.ScriptFullName);
  var sScriptDir = fileScript.ParentFolder.Path;
  /* all folders must have a trailing slash */
  if (sScriptDir.substring(sScriptDir.length - 1) != "\\")
    sScriptDir = sScriptDir + "\\";
  return sScriptDir;
} /* getScriptDir */

/*----------------------------------------------------------------------
Load modules
N.B.: All files "JScript.js" or "jscript.js" under 
"C:\Program Files\Microsoft Visual Studio 9.0" need to be saved as ANSI
in order to prevent Visual Studio from generating UTF-8 files, which
cannot be read by the FileSystemObject!!!
----------------------------------------------------------------------*/
/* console i/o */
if (typeof g_ciojs == "undefined") eval(g_fso.OpenTextFile(getScriptDir() + "cio.js", 1).ReadAll());
/* logging */
if (typeof g_logjs == "undefined") eval(g_fso.OpenTextFile(getScriptDir() + "log.js", 1).ReadAll());
/* file system utilities */
if (typeof g_fsujs == "undefined") eval(g_fso.OpenTextFile(getScriptDir() + "fsu.js", 1).ReadAll());
/* text I/O utilities */
if (typeof g_textjs == "undefined") eval(g_fso.OpenTextFile(getScriptDir() + "text.js", 1).ReadAll());
/* Swiss member of parliament utilities */
if (typeof g_chmpjs == "undefined") eval(g_fso.OpenTextFile(getScriptDir() + "chmp.js", 1).ReadAll());

/*----------------------------------------------------------------------
Instantiate global log object
----------------------------------------------------------------------*/
var g_log = new Log(g_bVerbose);

/*----------------------------------------------------------------------
Parameters object
----------------------------------------------------------------------*/
function Parameters()
{
  this.sOutputFile = Fsu.getDocumentsFolder() + "bv.txt";
  this.bForce = false;
} /* Parameters */

/*----------------------------------------------------------------------
displayHelp
----------------------------------------------------------------------*/
function displayHelp(parms)
{
  Cio.outln("Calling Syntax:")
  Cio.outln("cscript bundesversammlung.js [/h] | [/copy] | [/v] [/f] [<outputfile>]")
  Cio.outln("where");
  Cio.outln("  /h           displays calling syntax");
  Cio.outln("  /copy        displays copyright notice")
  Cio.outln("  /v           verbose");
  Cio.outln("  /f           if output file exists, delete it first");
  Cio.outln("  <outputfile> text file with mail addresses (default: " + parms.sOutputFile + ")");
};  /* displayHelp */

/*------------------------------------------------------------------------
getParameters
------------------------------------------------------------------------*/
function getParameters(parms)
{
  var parmsResult = null;
  var wsn = WScript.Arguments.Named;
  var wsu = WScript.Arguments.Unnamed;
  var cio = new Cio();
  /* /h for help */
  if (wsn.Exists("h") || wsn.Exists("?") || wsn.Exists("help"))
    displayHelp(parms);
  else if (wsn.Exists("copy"))
  {
    var sCopying = getScriptDir()+"..\\COPYING.txt";
    Cio.outln(sCopying);
    var ts = g_fso.OpenTextFile(sCopying,1)
    Cio.outln(ts.ReadAll());
    ts.Close();
  }
  else
  {
    if (wsu.count > 0)
      parms.sOutputFile = Fsu.makeAbsolute(wsu.Item(0));
    if (wsn.Exists("f"))
      parms.bForce = true;
    Cio.outln("Output file : "+parms.sOutputFile);
    if (parms.bForce)
      Cio.outln("Previous output file will be deleted.");
    parmsResult = parms;
  }
  return parmsResult;
};  /* getParameters */

/*----------------------------------------------------------------------
main
----------------------------------------------------------------------*/
function main()
{
  g_log.enter("main");
  Cio.outln(g_sProgram+": "+g_sBanner);
  g_log.event(g_sProgram+": "+g_sBanner);
  g_log.command();
  var iReturn = -1;
  var parms = new Parameters();
  parms = getParameters(parms);
  if (parms != null)
  {
    iReturn = 0;
    /* if file exists, either delete it or end processing */
    if (Fsu.fileExists(parms.sOutputFile))
    {
      if (parms.bForce)
      {
        if (Fsu.deleteFile(parms.sOutputFile,true))
          Cio.outln("\""+parms.sOutputFile+"\" deleted.");
      }
      if (Fsu.fileExists(parms.sOutputFile))
      {
        Cio.outln("\""+parms.sOutputFile+"\" could not be deleted!");
        iReturn = -1;
      }
    }
    Cio.outln("");
    if (iReturn == 0)
    {
      var chmp = new ChMp(ChMp.sURL_COUNCIL_STATES);
      var sAddresses = chmp.getMailAddresses(";",false);
      chmp = new ChMp(ChMp.sURL_NATIONAL_COUNCIL);
      sAddresses = sAddresses + "\n" + chmp.getMailAddresses(";",false);
      var text = new Text();
      text.open(parms.sOutputFile, Text.iIOMODE_FORWRITING, true, Text.iTRISTATE_ASCII);
      text.write(sAddresses);
      text.close();
    }
  }
  g_log.exit("main",String(iReturn));
  return iReturn;
};  /* main */

/*----------------------------------------------------------------------
start it and return the result code
----------------------------------------------------------------------*/
try { WScript.quit(main()); }
catch (e)
{
  WScript.Echo("Exception " + e.name + ": " + e.message);
};

/*--------------------------------------------------------------------*/
