/*== date.js ===========================================================
Date module for enhancing Date functionality.
Version     : $Id: date.js 477 2010-06-24 11:35:45Z hartwig $
Application : Utilities
Description : JScript module for enhancing Date functionality.
------------------------------------------------------------------------
Created    : 04.08.2008, Hartwig Thomas, Enter AG, Zurich
Copyright (c) 2009, Enter AG, Zurich, Switzerland, 2009
This file is part of the project Bundesversammlung.
date.js is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 2 of the License, or
any later version.
date.js is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with Bundesversammlung. If not, see <http://www.gnu.org/licenses/>.
======================================================================*/
/* Help avoid duplicate import */
var g_datejs = true;
/* Report loading */
if (g_bVerbose)
  WScript.StdOut.WriteLine("loading date.js");
  
/*======================================================================
Date enhancement
======================================================================*/
/*----------------------------------------------------------------------
(private static) replaceFormat replaces all occurrences of sChar in sDate 
with the values in sValue from right to left, filling the rest with 0s.
----------------------------------------------------------------------*/
Date.replaceFormat = function(sDate,sChar,sValue)
{
  var s;
  var bFound = true;
  var j = sValue.length;
  for (var i = sDate.lastIndexOf(sChar); bFound; i = sDate.lastIndexOf(sChar,i-1))
  {
    if (i >= 0)
    {
      if (j > 0)
      {
        j--;
	      s = sValue.substr(j,1);
      }
      else
	      s = "0";
      sDate = sDate.substr(0,i) + s + sDate.substr(i+1);
      if (i == 0)
        bFound = false;
    }
    else
      bFound = false;
  }
  return sDate;
}; /* replaceFormat */

/*----------------------------------------------------------------------
(private static) extractFormat examines all occurrences of sChar in sFormat
and extracts the corresponding character string from sDate.
----------------------------------------------------------------------*/
Date.extractFormat = function(sDate,sFormat,sChar)
{
  var sValue = "";
  var bFound = true;
  for (var i = sFormat.lastIndexOf(sChar); bFound; i = sFormat.lastIndexOf(sChar,i-1))
  {
    if (i >= 0)
    {
      if (i < sDate.length)
        sValue = sDate.charAt(i) + sValue;
      if (i == 0)
        bFound = false;
    }
    else
      bFound = false;
  }
  if (!sValue)
    sValue = "0";
  return sValue;
}; /* extractFormat */

/*----------------------------------------------------------------------
(public) format does usual formatting
----------------------------------------------------------------------*/
Date.prototype.format = function(sFormat)
{
  /* replace all y in sFormat by year */
  var sDate = sFormat;
  var sYear = this.getFullYear().toString();
  sDate = Date.replaceFormat(sDate,"y",sYear);
  var sMonth = (this.getMonth()+1).toString();
  sDate = Date.replaceFormat(sDate,"M",sMonth);
  var sDay = (this.getDate()).toString();
  sDate = Date.replaceFormat(sDate,"d",sDay);
  var sHours = (this.getHours()).toString();
  sDate = Date.replaceFormat(sDate,"h",sHours);
  var sMinutes = (this.getMinutes()).toString();
  sDate = Date.replaceFormat(sDate,"m",sMinutes);
  var sSeconds = (this.getSeconds()).toString();
  sDate = Date.replaceFormat(sDate,"s",sSeconds);
  var sMilliseconds = (this.getMilliseconds()).toString();
  sDate = Date.replaceFormat(sDate,"f",sMilliseconds);
  return sDate;
}; /* format */
 
/*----------------------------------------------------------------------
(public) parse does usual parsing
----------------------------------------------------------------------*/
Date.parse = function(sDate, sFormat)
{
  var date = new Date();
  /* extract all y in format */
  var sYear = Date.extractFormat(sDate,sFormat,"y");
  date.setFullYear(sYear);
  var sMonth = Date.extractFormat(sDate,sFormat,"M");
  date.setMonth(sMonth-1);
  var sDay = Date.extractFormat(sDate,sFormat,"d");
  date.setDate(sDay);
  var sHours = Date.extractFormat(sDate,sFormat,"h");
  date.setHours(sHours);
  var sMinutes = Date.extractFormat(sDate,sFormat,"m");
  date.setMinutes(sMinutes);
  var sSeconds = Date.extractFormat(sDate,sFormat,"s");
  date.setSeconds(sSeconds);
  var sMilliseconds = Date.extractFormat(sDate,sFormat,"f");
  date.setMilliseconds(sMilliseconds);
  return date;
}; /* parse */
 
/*----------------------------------------------------------------------
(public) timestamp returns a string for the date
----------------------------------------------------------------------*/
Date.prototype.timestamp = function()
{
  return this.format("dd.MM.yyyy hh:mm:ss.ffffff");
}; /* timestamp */
 
/*----------------------------------------------------------------------
(public static) tsNow returns current timestamp
----------------------------------------------------------------------*/
Date.tsNow = function()
{
  var dateNow = new Date();
  return dateNow.timestamp();
}; /* tsNow */

/*--------------------------------------------------------------------
(public, static) nowms current Date/Time im Milliseconds
--------------------------------------------------------------------*/
Date.nowms = function()
{
  return new Date().getTime();
}; /* nowms */

