/*== log.js ============================================================
Logging module.
Version     : $Id: log.js 477 2010-06-24 11:35:45Z hartwig $
Application : Utilities
Description : JScript module for logging.
------------------------------------------------------------------------
Created    : 04.08.2008, Hartwig Thomas, Enter AG, Zurich
Copyright (c) 2009, Enter AG, Zurich, Switzerland, 2009
This file is part of the project Bundesversammlung.
log.js is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 2 of the License, or
any later version.
log.js is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with Bundesversammlung. If not, see <http://www.gnu.org/licenses/>.
======================================================================*/
/* Help avoid duplicate import */
var g_logjs = true;
/* Report loading */
if (g_bVerbose)
  WScript.StdOut.WriteLine("loading log.js");
  
/*======================================================================
Log
======================================================================*/
/* date is needed for formatting timestamp of error messages */
if (typeof g_datejs == "undefined") 
  eval(g_fso.OpenTextFile(getScriptDir()+"date.js",1).ReadAll());
/* cio is needed for formatting timestamp of error messages */
if (typeof g_ciojs == "undefined")
  eval(g_fso.OpenTextFile(getScriptDir()+"cio.js",1).ReadAll());

/*----------------------------------------------------------------------
Log class (static, singleton)
----------------------------------------------------------------------*/
function Log(bDebug)
{
  this.bDebug = bDebug;
  this.sIndent = "";
}; /* Log */

/*----------------------------------------------------------------------
trace displays the given message, if bDebug is True
----------------------------------------------------------------------*/
Log.prototype.trace = function(sMessage)
{
  if (this.bDebug)
    Cio.outln(Date.tsNow() + " " + this.sIndent + sMessage);
}; /* trace */

/*----------------------------------------------------------------------
event traces messages
----------------------------------------------------------------------*/
Log.prototype.event = function(sMessage)
{
  if (this.bDebug)
     this.trace("--- "+sMessage);
}; /* event */

/*----------------------------------------------------------------------
enter traces function/procedure entry
----------------------------------------------------------------------*/
Log.prototype.enter = function(sProcedure,sParameters)
{
  if (this.bDebug)
  {
    var sMessage = ">>> " + sProcedure;
    if (sParameters)
      sMessage = sMessage + "(" + String(sParameters) + ")";
    this.trace(sMessage);
    this.sIndent = this.sIndent + "  ";
  }
}; /* enter */

/*----------------------------------------------------------------------
exit traces function/procedure exit
----------------------------------------------------------------------*/
Log.prototype.exit = function(sProcedure,sReturn)
{
  if (this.bDebug)
  {
    this.sIndent = this.sIndent.substring(0,this.sIndent.length-2);
    var sMessage = "<<< " + sProcedure;
    if (sReturn)
      sMessage = sMessage + "(" + String(sReturn) + ")";
    this.trace(sMessage);
  }
}; /* exit */

/*----------------------------------------------------------------------
except traces exception (unconditionally)
----------------------------------------------------------------------*/
Log.prototype.exception = function(sProcedure,e)
{
  if (e)
  {
    var sMessage = "!!! " + sProcedure;
    var iError = e.number & 0xFFFF; 
    sMessage = sMessage + " raised exception " + 
    iError.toString() + " (" + e.description + ")!";
    this.trace(sMessage);
  }
}; /* exception */

/*----------------------------------------------------------------------
command traces command line
----------------------------------------------------------------------*/
Log.prototype.command = function()
{
  if (this.bDebug)
  {
    var sArgs = "";
    for (var iArg = 0; iArg < WScript.Arguments.length; iArg++)
    {
      if (iArg > 0)
        sArgs = sArgs + " ";
      sArgs = sArgs + WScript.Arguments(iArg);
    }
    sCommand = WScript.ScriptFullName;
    if (sArgs.length > 0)
      sCommand = sCommand + " " + sArgs;
    this.event(sCommand);
  }
}; /* command */
